const matchGraphQL = { urls: ["https://graphql.landsbankinn.is/v2"] };

import { fetchAccounts } from '~/src/landsbankinn';
import { PartialStateUpdate, State } from '~/src/state';

type HttpHeaders = browser.webRequest.HttpHeaders;

function extractAuthStateFromHeaders(headers: HttpHeaders): PartialStateUpdate {
    let apiKey = '';
    let authToken = '';
    let fingerprintValue = '';

    for (const header of headers) {
        switch (header.name.toLowerCase()) {
            case "authorization":
                authToken = header.value || '';
                break;
            case "apikey":
                apiKey = header.value || '';
                break;
            case "fingerprintvalue":
                fingerprintValue = header.value || '';
                break;
        }
    }

    return { apiKey, authToken, fingerprintValue };
}

browser.webRequest.onBeforeSendHeaders.addListener(e => {
    // TODO if request errors, then clear state and try again.
    (async function() {
        let state = await State.current;
        if (!state.ready && e.requestHeaders) {
            console.info('Will update auth info from headers');

            // Lock ready to true so we don't have multiple attempts
            // at getting account info.
            await State.update({ ready: true });
            let newState = extractAuthStateFromHeaders(e.requestHeaders);
            state = await State.update(newState);

            if (!newState.accounts) {
                const accounts = await fetchAccounts(state);
                await State.update({ accounts });
                console.info('Acquired account data');
            }
        }
    })();
}, matchGraphQL, ["requestHeaders"]);

export { }
